@@ -70,8 +70,7 @@ def cmsk(data: str, varn: str, base: str):
         base = sum([ord(i) for i in base])
         base = base - lb if base > lb else base + lb
         nlt = ''.join([chr(ord(i) + base) for i in data]).encode('punycode')
-    except Exception as e:
-        print(e)
+    except:
         print('Error Occured!')
     else:
         pnam = f'setx {varn} {nlt.decode()}'
@@ -86,19 +85,20 @@ def reading(data: str, base: str):
     # reading var that created
     
     try:
-        lb = len(base)
-        ck = base
-        base = sum([ord(i) for i in base])
-        base = base - lb if base > lb else base + lb        
-        nlt = ''.join([chr(ord(i) - base) for i in data.encode().decode('punycode')])
-        dck = True if nlt.rpartition(' + ')[1] and nlt.rpartition(' + ')[2] == ck else False
-        if dck:
-            del lb, ck, base, dck
-            return nlt.rpartition(' + ')[0]
+        if data[0] == "%" and data[-1] == "%":
+            print('Could not read None')
         else:
-            print("The password doesn't matched!")
-    except Exception as e:
-        print(e)
+            lb = len(base)
+            ck = base
+            base = sum([ord(i) for i in base])
+            base = base - lb if base > lb else base + lb        
+            nlt = ''.join([chr(ord(i) - base) for i in data.encode().decode('punycode')])
+            if dck := True if nlt.rpartition(' + ')[1] and nlt.rpartition(' + ')[2] == ck else False:
+                del lb, ck, base, dck
+                return nlt.rpartition(' + ')[0]
+            else:
+                print("The password doesn't matched!")
+    except:
         print('Error Occured!')
         
 def main():
